==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/sid/translations/sid_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="77"/>
        <source>SID Plugin</source>
        <translation>SID-Modul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="79"/>
        <source>SID Files</source>
        <translation>SID-Dateien</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="133"/>
        <source>About SID Audio Plugin</source>
        <translation>Über SID-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="134"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Qmmp SID-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="135"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Dieses Modul spielt Commodore-64-Musikdateien unter Verwendung der Bibliothek libsidplayfp ab</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Einstellungen SID-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Schnelle Abtastratenkonvertierung</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>HVSC-Datenbankdatei:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Abtastratenkonvertierungsverfahren:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Standardeinstellungen Liedlänge, Sek.:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>HVSC-Liedlängendatenbank aktivieren</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulation:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/sid/translations/sid_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="59"/>
        <source>SID Plugin</source>
        <translation>SID-Modul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="61"/>
        <source>SID Files</source>
        <translation>SID-Dateien</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="115"/>
        <source>About SID Audio Plugin</source>
        <translation>Über SID-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="116"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Qmmp SID-Audiomodul</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="117"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Dieses Modul spielt Commodore-64-Musikdateien unter Verwendung der Bibliothek libsidplayfp ab</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="118"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Einstellungen SID-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Schnelle Abtastratenkonvertierung</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Abtastrate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>HVSC-Datenbankdatei:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Abtastratenkonvertierungsverfahren:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Standardeinstellungen Liedlänge, Sek.:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>HVSC-Liedlängendatenbank aktivieren</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulation:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
